@@ -16,6 +16,12 @@ for (alt in c("two.sided", "greater", "less")) {
     expect_true(test$p.value > .05)
   })
 
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
+
   # .0499 instead of .05 b/c of floating point error associated with convergence.
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
@@ -44,6 +50,12 @@ for (alt in c("two.sided", "greater")) {
     expect_true(test$p.value <= .05)
   })
 
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
+
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
   pval <- pmin(
@@ -71,6 +83,12 @@ for (alt in c("two.sided", "less")) {
     expect_true(test$p.value <= .05)
   })
 
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
+
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
   pval <- pmin(
@@ -130,6 +148,12 @@ for (alt in c("two.sided", "greater", "less")) {
     expect_true(test$p.value > .05)
   })
 
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
+
   # .0499 instead of .05 b/c of floating point error associated with convergence.
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
@@ -158,6 +182,12 @@ for (alt in c("two.sided", "greater")) {
     expect_true(test$p.value <= .05)
   })
 
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
+
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
   pval <- pmin(
@@ -185,6 +215,12 @@ for (alt in c("two.sided", "less")) {
     expect_true(test$p.value <= .05)
   })
 
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
+
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
   pval <- pmin(
@@ -240,9 +276,19 @@ for (alt in c("two.sided", "greater", "less")) {
     expect_true(all(names(test) == c("statistic", "p.value", "conf.int", "conf.level", "alternative")))
   })
 
+  alt2 <- ifelse(alt == "greater", "less", ifelse(alt == "less", "greater", "two.sided"))
+  test_02 <- gamma_scale_one_sample(x, 1 / 1, alt2)
   test_that("Check contents", {
     expect_true(test$p.value > .05)
+    expect_equal(test$p.value, test_02$p.value)
   })
+  rm(alt2, test_02)
+
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
 
   # .0499 instead of .05 b/c of floating point error associated with convergence.
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
@@ -268,9 +314,19 @@ for (alt in c("two.sided", "greater")) {
     expect_true(all(names(test) == c("statistic", "p.value", "conf.int", "conf.level", "alternative")))
   })
 
+  alt2 <- ifelse(alt == "greater", "less", ifelse(alt == "less", "greater", "two.sided"))
+  test_02 <- gamma_scale_one_sample(x, 1 / 1, alt2)
   test_that("Check contents", {
     expect_true(test$p.value <= .05)
+    expect_equal(test$p.value, test_02$p.value)
   })
+  rm(alt2, test_02)
+
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
 
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
@@ -295,9 +351,19 @@ for (alt in c("two.sided", "less")) {
     expect_true(all(names(test) == c("statistic", "p.value", "conf.int", "conf.level", "alternative")))
   })
 
+  alt2 <- ifelse(alt == "greater", "less", ifelse(alt == "less", "greater", "two.sided"))
+  test_02 <- gamma_scale_one_sample(x, 1 / 3, alt2)
   test_that("Check contents", {
     expect_true(test$p.value <= .05)
+    expect_equal(test$p.value, test_02$p.value)
   })
+  rm(alt2, test_02)
+
+  if (alt == "two.sided") {
+    test_that("check contents", {
+      expect_true(test$statistic >= 0)
+    })
+  }
 
   CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
   CI2 <- test$conf.int[2] - .Machine$double.eps
@@ -357,6 +423,7 @@ test_that("Check structure.", {
 
 test_that("Check contents", {
   expect_true(test$p.value > .05)
+  expect_true(test$statistic >= 0)
 })
 
 # make sure CIs match
@@ -384,7 +451,8 @@ test_that("Check structure.", {
 })
 
 test_that("Check contents", {
-  expect_true(test$p.value < .05)
+  expect_true(test$p.value <= .05)
+  expect_true(test$statistic >= 0)
 })
 
 # make sure CIs match
@@ -442,6 +510,7 @@ test_that("Check structure.", {
 
 test_that("Check contents", {
   expect_true(test$p.value > .05)
+  expect_true(test$statistic >= 0)
 })
 
 # make sure CIs match
@@ -469,7 +538,8 @@ test_that("Check structure.", {
 })
 
 test_that("Check contents", {
-  expect_true(test$p.value < .05)
+  expect_true(test$p.value <= .05)
+  expect_true(test$statistic >= 0)
 })
 
 # make sure CIs match
@@ -527,6 +597,7 @@ test_that("Check structure.", {
 
 test_that("Check contents", {
   expect_true(test$p.value > .05)
+  expect_true(test$statistic >= 0)
 })
 
 # make sure CIs match
@@ -554,7 +625,8 @@ test_that("Check structure.", {
 })
 
 test_that("Check contents", {
-  expect_true(test$p.value < .05)
+  expect_true(test$p.value <= .05)
+  expect_true(test$statistic >= 0)
 })
 
 # make sure CIs match
